Callback class

Callback information

Constructors

Callback({required int timestamp, required String callbackId, String? payload, required User user})
const
Callback.fromJson(Map<String, dynamic> json)
factory

Properties

callbackId String
final
hashCode int
The hash code for this object.
no setterinherited
payload String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final
user User
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited