ChatMember class

Chat member

Constructors

ChatMember({required int userId, required String name, String? username, required bool isBot, required int lastActivityTime, String? description, String? avatarUrl, String? fullAvatarUrl, required int lastAccessTime, required bool isOwner, required bool isAdmin, required int joinTime, List<ChatPermissions>? permissions})
const
ChatMember.fromJson(Map<String, dynamic> json)
factory

Properties

avatarUrl String?
final
description String?
final
fullAvatarUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
isAdmin bool
final
isBot bool
final
isOwner bool
final
joinTime int
final
lastAccessTime int
final
lastActivityTime int
final
name String
final
permissions List<ChatPermissions>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
final
username String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited