LaunchOptions class

Launch options

Constructors

LaunchOptions({List<UpdateType>? allowedUpdates, int? marker, void onMarkerChanged(int)?, void onPollError(Object error, StackTrace? stack)?, void onPollSuccess()?, bool dropPendingUpdates = false, bool processUpdatesConcurrently = false})
const

Properties

allowedUpdates List<UpdateType>?
final
dropPendingUpdates bool
final
hashCode int
The hash code for this object.
no setterinherited
marker int?
final
onMarkerChanged → void Function(int)?
final
onPollError → void Function(Object error, StackTrace? stack)?
final
onPollSuccess → void Function()?
final
processUpdatesConcurrently bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited