MessageCallbackUpdate class

Message callback update

Inheritance

Constructors

MessageCallbackUpdate({required int timestamp, required Callback callback, Message? message, String? userLocale})
const
MessageCallbackUpdate.fromJson(Map<String, dynamic> json)
factory

Properties

callback Callback
final
hashCode int
The hash code for this object.
no setterinherited
message Message?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
finalinherited
updateType UpdateType
finalinherited
userLocale String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited