MessageConstructedUpdate class

Message constructed update

Inheritance

Constructors

MessageConstructedUpdate({required int timestamp, required User user, required String sessionId, required ConstructedMessage message})
const
MessageConstructedUpdate.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message ConstructedMessage
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
timestamp int
finalinherited
updateType UpdateType
finalinherited
user User
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited