LinkMarkup class

Link markup

Inheritance

Constructors

LinkMarkup({required int from, required int length, required String url})
const
LinkMarkup.fromJson(Map<String, dynamic> json)
factory

Properties

from int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited