UnknownMarkup class

Unknown markup fallback for forward compatibility

Inheritance

Constructors

UnknownMarkup({required String type, required int from, required int length, required Map<String, dynamic> raw})
const
UnknownMarkup.fromJson(Map<String, dynamic> json)
factory

Properties

from int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
finalinherited
raw Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited