Chat class
Represents a chat
Constructors
-
Chat({required int chatId, required ChatType type, required ChatStatus status, String? title, ChatIcon? icon, required int lastEventTime, required int participantsCount, int? ownerId, Map<
String, int?> ? participants, required bool isPublic, String? link, String? description, Map<String, dynamic> ? dialogWithUser, int? messagesCount, String? chatMessageId, Map<String, dynamic> ? pinnedMessage}) -
const
-
Chat.fromJson(Map<
String, dynamic> json) -
factory
Properties
- chatId → int
-
final
- chatMessageId → String?
-
final
- description → String?
-
final
-
dialogWithUser
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → ChatIcon?
-
final
- isPublic → bool
-
final
- lastEventTime → int
-
final
- link → String?
-
final
- messagesCount → int?
-
final
- ownerId → int?
-
final
-
participants
→ Map<
String, int?> ? -
final
- participantsCount → int
-
final
-
pinnedMessage
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ChatStatus
-
final
- title → String?
-
final
- type → ChatType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited