Message class
Message
Constructors
- Message({MessageSender? sender, required MessageRecipient recipient, required int timestamp, LinkedMessage? link, required MessageBody body, MessageStat? stat, String? url, MessageConstructor? constructor})
-
const
-
Message.fromJson(Map<
String, dynamic> json) -
factory
Properties
- body → MessageBody
-
final
- constructor → MessageConstructor?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → LinkedMessage?
-
final
- recipient → MessageRecipient
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → MessageSender?
-
final
- stat → MessageStat?
-
final
- timestamp → int
-
final
- url → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited